# -*- coding: utf-8 -*-
# License: Apache License 2.0
"""Functions related to feature extraction.

    :author: Patrick L. Lange (plange@ets.org)
    :author: Rutuja Ubale (rutuja@ucla.edu)
    :organization: ETS

"""
from skll import FeatureSet


def bow(words_list, vocab):
    """This function computes bag of word features.

    Args:
        words_list (list of word array): Each word array corresponds to a
            sentence that should be converted into bag of word features.
        vocab (list of vocab array): Vocabulary that should be used to compute
            the bag of word features.

    Returns:
        skll.FeatureSet

    """
    ids = []
    labels = []
    samples = []

    for sample in words_list:
        mapping = {}
        for word in sample:
            if word in mapping:
                mapping[word] += 1
            else:
                mapping[word] = 1
        samples.append(mapping)

    for sample in samples:
        ids.append(range(len(sample)))
        labels.append([None])

    return FeatureSet("Samples",
                      ids,
                      labels,
                      samples)
